====================================
Sample-based Quantum Diagonalization
====================================

.. _qiskit_addon_sqd:

.. automodule:: qiskit_addon_sqd
   :no-members:
   :no-inherited-members:
   :no-special-members:
